summaryrefslogtreecommitdiffstats
path: root/src/kernel/qimage.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/kernel/qimage.cpp')
-rw-r--r--src/kernel/qimage.cpp82
1 files changed, 41 insertions, 41 deletions
diff --git a/src/kernel/qimage.cpp b/src/kernel/qimage.cpp
index b55a0e7..3984e67 100644
--- a/src/kernel/qimage.cpp
+++ b/src/kernel/qimage.cpp
@@ -427,9 +427,9 @@ QImage::QImage( const char * const xpm[] )
#ifndef QT_NO_IMAGEIO_XPM
read_xpm_image_or_array( 0, xpm, *this );
#else
// We use a qFatal rather than disabling the whole function, as this
// constructor may be ambiguous.
- qFatal("XPM not supported");
+ tqFatal("XPM not supported");
#endif
}
@@ -588,7 +588,7 @@ QImage QImage::fromMimeSource( const QString &abs_name )
const QMimeSource *m = QMimeSourceFactory::defaultFactory()->data( abs_name );
if ( !m ) {
#if defined(QT_CHECK_STATE)
- qWarning("QImage::fromMimeSource: Cannot find image \"%s\" in the mime source factory", abs_name.latin1() );
+ tqWarning("QImage::fromMimeSource: Cannot find image \"%s\" in the mime source factory", abs_name.latin1() );
#endif
return QImage();
}
@@ -944,7 +944,7 @@ QImage QImage::copy(int x, int y, int w, int h, int conversion_flags) const
void QImage::warningIndexRange( const char *func, int i )
{
#if defined(QT_CHECK_RANGE)
- qWarning( "QImage::%s: Index %d out of range", func, i );
+ tqWarning( "QImage::%s: Index %d out of range", func, i );
#else
Q_UNUSED( func )
Q_UNUSED( i )
@@ -1091,7 +1091,7 @@ QImage::Endian QImage::systemByteOrder()
if ( sbo == IgnoreEndian ) { // initialize
int ws;
bool be;
- qSysInfo( &ws, &be );
+ tqSysInfo( &ws, &be );
sbo = be ? BigEndian : LittleEndian;
}
return sbo;
@@ -1242,7 +1242,7 @@ bool QImage::create( int width, int height, int depth, int numColors,
return FALSE; // invalid parameter(s)
if ( depth == 1 && bitOrder == IgnoreEndian ) {
#if defined(QT_CHECK_RANGE)
- qWarning( "QImage::create: Bit order is required for 1 bpp images" );
+ tqWarning( "QImage::create: Bit order is required for 1 bpp images" );
#endif
return FALSE;
}
@@ -1251,7 +1251,7 @@ bool QImage::create( int width, int height, int depth, int numColors,
#if defined(QT_CHECK_RANGE)
if ( depth == 24 )
- qWarning( "QImage::create: 24-bpp images no longer supported, "
+ tqWarning( "QImage::create: 24-bpp images no longer supported, "
"use 32-bpp instead" );
#endif
switch ( depth ) {
@@ -2162,9 +2162,9 @@ QImage QImage::convertDepth( int depth, int conversion_flags ) const
else {
#if defined(QT_CHECK_RANGE)
if ( isNull() )
- qWarning( "QImage::convertDepth: Image is a null image" );
+ tqWarning( "QImage::convertDepth: Image is a null image" );
else
- qWarning( "QImage::convertDepth: Depth %d not supported", depth );
+ tqWarning( "QImage::convertDepth: Depth %d not supported", depth );
#endif
}
return image;
@@ -2206,7 +2206,7 @@ int QImage::pixelIndex( int x, int y ) const
{
#if defined(QT_CHECK_RANGE)
if ( x < 0 || x >= width() ) {
- qWarning( "QImage::pixel: x=%d out of range", x );
+ tqWarning( "QImage::pixel: x=%d out of range", x );
return -12345;
}
#endif
@@ -2225,7 +2225,7 @@ int QImage::pixelIndex( int x, int y ) const
#endif
case 32:
#if defined(QT_CHECK_RANGE)
- qWarning( "QImage::pixelIndex: Not applicable for %d-bpp images "
+ tqWarning( "QImage::pixelIndex: Not applicable for %d-bpp images "
"(no palette)", depth() );
#endif
return 0;
@@ -2248,7 +2248,7 @@ QRgb QImage::pixel( int x, int y ) const
{
#if defined(QT_CHECK_RANGE)
if ( x < 0 || x >= width() ) {
- qWarning( "QImage::pixel: x=%d out of range", x );
+ tqWarning( "QImage::pixel: x=%d out of range", x );
return 12345;
}
#endif
@@ -2292,7 +2292,7 @@ void QImage::setPixel( int x, int y, uint index_or_rgb )
{
if ( x < 0 || x >= width() ) {
#if defined(QT_CHECK_RANGE)
- qWarning( "QImage::setPixel: x=%d out of range", x );
+ tqWarning( "QImage::setPixel: x=%d out of range", x );
#endif
return;
}
@@ -2300,7 +2300,7 @@ void QImage::setPixel( int x, int y, uint index_or_rgb )
uchar * s = scanLine( y );
if ( index_or_rgb > 1) {
#if defined(QT_CHECK_RANGE)
- qWarning( "QImage::setPixel: index=%d out of range",
+ tqWarning( "QImage::setPixel: index=%d out of range",
index_or_rgb );
#endif
} else if ( bitOrder() == QImage::LittleEndian ) {
@@ -2317,7 +2317,7 @@ void QImage::setPixel( int x, int y, uint index_or_rgb )
} else if ( depth() == 8 ) {
if (index_or_rgb > (uint)numColors()) {
#if defined(QT_CHECK_RANGE)
- qWarning( "QImage::setPixel: index=%d out of range",
+ tqWarning( "QImage::setPixel: index=%d out of range",
index_or_rgb );
#endif
return;
@@ -2789,7 +2789,7 @@ QImage QImage::smoothScale( const QSize& s, ScaleMode mode ) const
{
if ( isNull() ) {
#if defined(QT_CHECK_RANGE)
- qWarning( "QImage::smoothScale: Image is a null image" );
+ tqWarning( "QImage::smoothScale: Image is a null image" );
#endif
return copy();
}
@@ -2854,7 +2854,7 @@ QImage QImage::scale( const QSize& s, ScaleMode mode ) const
{
if ( isNull() ) {
#if defined(QT_CHECK_RANGE)
- qWarning( "QImage::scale: Image is a null image" );
+ tqWarning( "QImage::scale: Image is a null image" );
#endif
return copy();
}
@@ -2892,7 +2892,7 @@ QImage QImage::scaleWidth( int w ) const
{
if ( isNull() ) {
#if defined(QT_CHECK_RANGE)
- qWarning( "QImage::scaleWidth: Image is a null image" );
+ tqWarning( "QImage::scaleWidth: Image is a null image" );
#endif
return copy();
}
@@ -2921,7 +2921,7 @@ QImage QImage::scaleHeight( int h ) const
{
if ( isNull() ) {
#if defined(QT_CHECK_RANGE)
- qWarning( "QImage::scaleHeight: Image is a null image" );
+ tqWarning( "QImage::scaleHeight: Image is a null image" );
#endif
return copy();
}
@@ -3336,7 +3336,7 @@ QImage QImage::swapRGB() const
}
#ifndef QT_NO_IMAGE_16_BIT
} else if ( depth() == 16 ) {
- qWarning( "QImage::swapRGB not implemented for 16bpp" );
+ tqWarning( "QImage::swapRGB not implemented for 16bpp" );
#endif
} else
#endif //QT_NO_IMAGE_TRUECOLOR
@@ -3562,7 +3562,7 @@ bool QImage::doImageIO( QImageIO* io, int quality ) const
io->setImage( *this );
#if defined(QT_CHECK_RANGE)
if ( quality > 100 || quality < -1 )
- qWarning( "QPixmap::save: quality out of range [-1,100]" );
+ tqWarning( "QPixmap::save: quality out of range [-1,100]" );
#endif
if ( quality >= 0 )
io->setQuality( QMIN(quality,100) );
@@ -3899,7 +3899,7 @@ void qt_init_image_handlers() // initialize image handlers
imageHandlers = new QIHList;
Q_CHECK_PTR( imageHandlers );
imageHandlers->setAutoDelete( TRUE );
- qAddPostRoutine( cleanup );
+ tqAddPostRoutine( cleanup );
#ifndef QT_NO_IMAGEIO_BMP
QImageIO::defineIOHandler( "BMP", "^BM", 0,
read_bmp_image, write_bmp_image );
@@ -4199,7 +4199,7 @@ void QImageIO::setParameters( const char *parameters )
{
if ( d && d->parameters )
delete [] (char*)d->parameters;
- d->parameters = qstrdup( parameters );
+ d->parameters = tqstrdup( parameters );
}
/*!
@@ -4502,7 +4502,7 @@ bool QImageIO::write()
}
if ( !h || !h->write_image ) {
#if defined(QT_CHECK_RANGE)
- qWarning( "QImageIO::write: No such image format handler: %s",
+ tqWarning( "QImageIO::write: No such image format handler: %s",
format() );
#endif
return FALSE;
@@ -4637,19 +4637,19 @@ bool read_dib( QDataStream& s, int offset, int startpos, QImage& image )
if ( d->atEnd() ) // end of stream/file
return FALSE;
#if 0
- qDebug( "offset...........%d", offset );
- qDebug( "startpos.........%d", startpos );
- qDebug( "biSize...........%d", bi.biSize );
- qDebug( "biWidth..........%d", bi.biWidth );
- qDebug( "biHeight.........%d", bi.biHeight );
- qDebug( "biPlanes.........%d", bi.biPlanes );
- qDebug( "biBitCount.......%d", bi.biBitCount );
- qDebug( "biCompression....%d", bi.biCompression );
- qDebug( "biSizeImage......%d", bi.biSizeImage );
- qDebug( "biXPelsPerMeter..%d", bi.biXPelsPerMeter );
- qDebug( "biYPelsPerMeter..%d", bi.biYPelsPerMeter );
- qDebug( "biClrUsed........%d", bi.biClrUsed );
- qDebug( "biClrImportant...%d", bi.biClrImportant );
+ tqDebug( "offset...........%d", offset );
+ tqDebug( "startpos.........%d", startpos );
+ tqDebug( "biSize...........%d", bi.biSize );
+ tqDebug( "biWidth..........%d", bi.biWidth );
+ tqDebug( "biHeight.........%d", bi.biHeight );
+ tqDebug( "biPlanes.........%d", bi.biPlanes );
+ tqDebug( "biBitCount.......%d", bi.biBitCount );
+ tqDebug( "biCompression....%d", bi.biCompression );
+ tqDebug( "biSizeImage......%d", bi.biSizeImage );
+ tqDebug( "biXPelsPerMeter..%d", bi.biXPelsPerMeter );
+ tqDebug( "biYPelsPerMeter..%d", bi.biYPelsPerMeter );
+ tqDebug( "biClrUsed........%d", bi.biClrUsed );
+ tqDebug( "biClrImportant...%d", bi.biClrImportant );
#endif
int w = bi.biWidth, h = bi.biHeight, nbits = bi.biBitCount;
int t = bi.biSize, comp = bi.biCompression;
@@ -5758,7 +5758,7 @@ static void read_xpm_image_or_array( QImageIO * iio, const char * const * source
for( currentColor=0; currentColor < ncols; ++currentColor ) {
if ( !read_xpm_string( buf, d, source, index ) ) {
#if defined(QT_CHECK_RANGE)
- qWarning( "QImage: XPM color specification missing");
+ tqWarning( "QImage: XPM color specification missing");
#endif
return;
}
@@ -5769,7 +5769,7 @@ static void read_xpm_image_or_array( QImageIO * iio, const char * const * source
i = nextColorSpec(buf);
if ( i < 0 ) {
#if defined(QT_CHECK_RANGE)
- qWarning( "QImage: XPM color specification is missing: %s", buf.data());
+ tqWarning( "QImage: XPM color specification is missing: %s", buf.data());
#endif
return; // no c/g/g4/m/s specification at all
}
@@ -5809,7 +5809,7 @@ static void read_xpm_image_or_array( QImageIO * iio, const char * const * source
for( int y=0; y<h; y++ ) {
if ( !read_xpm_string( buf, d, source, index ) ) {
#if defined(QT_CHECK_RANGE)
- qWarning( "QImage: XPM pixels missing on image line %d", y);
+ tqWarning( "QImage: XPM pixels missing on image line %d", y);
#endif
return;
}
@@ -6478,7 +6478,7 @@ QGfx * QImage::graphicsContext()
int h = qt_screen->mapToDevice( QSize(width(),height()) ).height();
ret=QGfx::createGfx(depth(),bits(),w,h,bytesPerLine());
} else {
- qDebug("Trying to create image for null depth");
+ tqDebug("Trying to create image for null depth");
return 0;
}
if(depth()<=8) {
@@ -427,9 +427,9 @@ QImage::QImage( const char * const xpm[] )
read_xpm_image_or_array( 0, xpm, *this );
#else
- // We use a qFatal rather than disabling the whole function, as this
+ // We use a tqFatal rather than disabling the whole function, as this
// constructor may be ambiguous.